==> libreswan-3.30.tar.gz: libreswan-3.30/testing/pluto/impair-09-protected-ikev1/westrun.sh <==
# Proper test connection, should work
ipsec whack --impair none
../bin/libreswan-up-down.sh  westnet-eastnet -I 192.0.1.254 192.0.2.254

# Quick:
ipsec whack --impair none
ipsec whack --impair revival
ipsec whack --impair suppress-retransmits
ipsec whack --impair v1-hash-exchange:quick
# HASH payload omited - should fail
ipsec whack --impair v1-hash-payload:omit
../bin/libreswan-up-down.sh  westnet-eastnet -I 192.0.1.254 192.0.2.254
# HASH payload empty - should fail
ipsec whack --impair v1-hash-payload:empty
../bin/libreswan-up-down.sh  westnet-eastnet -I 192.0.1.254 192.0.2.254
# HASH payload badly calculated - should fail
ipsec whack --impair v1-hash-payload:0
../bin/libreswan-up-down.sh  westnet-eastnet -I 192.0.1.254 192.0.2.254
echo done

# Delete
ipsec whack --impair none
ipsec whack --impair revival
ipsec whack --impair suppress-retransmits
ipsec whack --impair v1-hash-exchange:delete
# HASH payload omited - should fail
ipsec whack --impair v1-hash-payload:omit
../bin/libreswan-up-down.sh  westnet-eastnet -I 192.0.1.254 192.0.2.254
# HASH payload empty - should fail
ipsec whack --impair v1-hash-payload:empty
../bin/libreswan-up-down.sh  westnet-eastnet -I 192.0.1.254 192.0.2.254
# HASH payload badly calculated - should fail
ipsec whack --impair v1-hash-payload:0
../bin/libreswan-up-down.sh  westnet-eastnet -I 192.0.1.254 192.0.2.254
echo done

# XAUTH:
ipsec whack --impair none
ipsec whack --impair revival
ipsec whack --impair suppress-retransmits
ipsec whack --impair v1-hash-exchange:xauth
# HASH payload omited - should fail
ipsec whack --impair v1-hash-payload:omit
../bin/libreswan-up-down.sh  westnet-eastnet -I 192.0.1.254 192.0.2.254
# HASH payload empty - should fail
ipsec whack --impair v1-hash-payload:empty
../bin/libreswan-up-down.sh  westnet-eastnet -I 192.0.1.254 192.0.2.254
# HASH payload badly calculated - should fail
ipsec whack --impair v1-hash-payload:0
../bin/libreswan-up-down.sh  westnet-eastnet -I 192.0.1.254 192.0.2.254
echo done

# INFO
ipsec whack --impair none
ipsec whack --impair revival
ipsec whack --impair suppress-retransmits
ipsec whack --impair v1-hash-exchange:notification
# HASH payload omited - should fail
ipsec whack --impair v1-hash-payload:omit
../bin/libreswan-up-down.sh  westnet-eastnet -I 192.0.1.254 192.0.2.254
# HASH payload empty - should fail
ipsec whack --impair v1-hash-payload:empty
../bin/libreswan-up-down.sh  westnet-eastnet -I 192.0.1.254 192.0.2.254
# HASH payload badly calculated - should fail
ipsec whack --impair v1-hash-payload:0
../bin/libreswan-up-down.sh  westnet-eastnet -I 192.0.1.254 192.0.2.254
echo done

==> libreswan_4.3.orig.tar.gz: libreswan-4.3/testing/pluto/impair-09-protected-ikev1/westrun.sh <==
# Proper test connection, should work
ipsec whack --impair none
ipsec whack --impair suppress-retransmits
../bin/libreswan-up-down.sh  westnet-eastnet -I 192.0.1.254 192.0.2.254

# Quick:
ipsec whack --impair none
ipsec whack --impair revival
ipsec whack --impair suppress-retransmits
ipsec whack --impair v1-hash-exchange:quick
# HASH payload omitted - should fail
ipsec whack --impair v1-hash-payload:omit
../bin/libreswan-up-down.sh  westnet-eastnet -I 192.0.1.254 192.0.2.254
# HASH payload empty - should fail
ipsec whack --impair v1-hash-payload:empty
../bin/libreswan-up-down.sh  westnet-eastnet -I 192.0.1.254 192.0.2.254
# HASH payload badly calculated - should fail
ipsec whack --impair v1-hash-payload:0
../bin/libreswan-up-down.sh  westnet-eastnet -I 192.0.1.254 192.0.2.254
echo done

# Delete
ipsec whack --impair none
ipsec whack --impair revival
ipsec whack --impair suppress-retransmits
ipsec whack --impair v1-hash-exchange:delete
# HASH payload omitted - should fail
ipsec whack --impair v1-hash-payload:omit
../bin/libreswan-up-down.sh  westnet-eastnet -I 192.0.1.254 192.0.2.254
# HASH payload empty - should fail
ipsec whack --impair v1-hash-payload:empty
../bin/libreswan-up-down.sh  westnet-eastnet -I 192.0.1.254 192.0.2.254
# HASH payload badly calculated - should fail
ipsec whack --impair v1-hash-payload:0
../bin/libreswan-up-down.sh  westnet-eastnet -I 192.0.1.254 192.0.2.254
echo done

# XAUTH:
ipsec whack --impair none
ipsec whack --impair revival
ipsec whack --impair suppress-retransmits
ipsec whack --impair v1-hash-exchange:xauth
# HASH payload omitted - should fail
ipsec whack --impair v1-hash-payload:omit
../bin/libreswan-up-down.sh  westnet-eastnet -I 192.0.1.254 192.0.2.254
# HASH payload empty - should fail
ipsec whack --impair v1-hash-payload:empty
../bin/libreswan-up-down.sh  westnet-eastnet -I 192.0.1.254 192.0.2.254
# HASH payload badly calculated - should fail
ipsec whack --impair v1-hash-payload:0
../bin/libreswan-up-down.sh  westnet-eastnet -I 192.0.1.254 192.0.2.254
echo done

# INFO
ipsec whack --impair none
ipsec whack --impair revival
ipsec whack --impair suppress-retransmits
ipsec whack --impair v1-hash-exchange:notification
# HASH payload omitted - should fail
ipsec whack --impair v1-hash-payload:omit
../bin/libreswan-up-down.sh  westnet-eastnet -I 192.0.1.254 192.0.2.254
# HASH payload empty - should fail
ipsec whack --impair v1-hash-payload:empty
../bin/libreswan-up-down.sh  westnet-eastnet -I 192.0.1.254 192.0.2.254
# HASH payload badly calculated - should fail
ipsec whack --impair v1-hash-payload:0
../bin/libreswan-up-down.sh  westnet-eastnet -I 192.0.1.254 192.0.2.254
echo done
